@@ -12,7 +12,7 @@ use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
 use super::Config;
 #[derive(Debug, Default)]
 pub(super) struct Operations {
-    rename: AHashMap<Id, JsWord>,
+    pub rename: AHashMap<Id, JsWord>,
     symbols: AHashSet<JsWord>,
 }
 
@@ -39,7 +39,7 @@ impl Operations {
     }
 }
 
-pub(super) struct Operator<'a>(pub &'a Operations, pub Config);
+pub(super) struct Operator<'a>(pub &'a AHashMap<Id, JsWord>, pub Config);
 
 impl Operator<'_> {
     fn keep_class_name(&mut self, ident: &mut Ident, class: &mut Class) -> Option<ClassExpr> {
@@ -56,11 +56,7 @@ impl Operator<'_> {
 
             rename.insert(ident.to_id(), orig_name.sym.clone());
 
-            let ops = Operations {
-                rename,
-                symbols: Default::default(),
-            };
-            let mut operator = Operator(&ops, self.1.clone());
+            let mut operator = Operator(&rename, self.1.clone());
 
             class.visit_mut_with(&mut operator);
         }
@@ -418,7 +414,7 @@ impl VisitMut for VarFolder<'_, '_> {
 impl<'a> Operator<'a> {
     /// Returns `Ok(renamed_ident)` if ident should be renamed.
     fn rename_ident(&mut self, ident: &mut Ident) -> Result<(), ()> {
-        if let Some(sym) = self.0.rename.get(&ident.to_id()) {
+        if let Some(sym) = self.0.get(&ident.to_id()) {
             ident.span = ident.span.with_ctxt(SyntaxContext::empty());
             ident.sym = sym.clone();
             return Ok(());
